@@ -50,6 +50,8 @@ class ToSystemcStm(ToSystemcExpr):
         self.visit_doc(o)
         w("void ")
         w(o.labels[0])
+        if o.trigger_constrain is not None:
+            raise NotImplementedError()
         if isinstance(o.body, HdlStmBlock):
             w("() ")
             self.visit_HdlStmBlock(o.body)
@@ -67,7 +69,7 @@ class ToSystemcStm(ToSystemcExpr):
     def visit_HdlStmAssign(self, o):
         """
         :type o: HdlStmAssign
-        :return: True if requires ;\n after end
+        :return: True if requires ;\\n after end
         """
         self.visit_doc(o)
         w = self.out.write
@@ -80,12 +82,14 @@ class ToSystemcStm(ToSystemcExpr):
         """
         :type o: HdlStmCase
 
-        :return: True if requires ;\n after end
+        :return: True if requires ;\\n after end
         """
         self.visit_doc(o)
         w = self.out.write
         if o.type != HdlStmCaseType.CASE:
             raise NotImplementedError()
+        if o.uniq_constrain is not None:
+            raise NotImplementedError()
         w("switch(")
         self.visit_iHdlExpr(o.switch_on)
         w(") {\n")
